from cdnmon.model.cdn import BGPViewCIDR
from cdnmon.model.cdn import CNAMEPattern
from cdnmon.model.cdn import CommonCDN

CDN = CommonCDN(
    name="wangsu",
    asn_patterns=["wangsu"],
    cname_suffixes=[
        CNAMEPattern(suffix=".6655.la", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".7678.info", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".8686c.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".90kuai.net", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".94kuai.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".akadns.net.cn", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".akadns88.net", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".akadns99.net", source="https://beian.miit.gov.cn/", is_leaf=True),
        CNAMEPattern(suffix=".akamaiedge.net.cn", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".akamaiedge88.net", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".akamaihd-staging.net.cn", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".akamaihd-staging88.net", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".akamaihd.net.cn", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".akamaihd88.net", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".akamaitech.net.cn", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".akamaitech88.net", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".akamaized88.net", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".akasrip.net.cn", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".akasrip88.net", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".akasripcn.net.cn", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".akdns.net.cn", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".allchdlb.cn", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".anjuke.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".battlenet.com.cn", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".bigops.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".bjhlgw.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".cdn20.com", source="https://beian.miit.gov.cn/", is_leaf=True),
        CNAMEPattern(suffix=".cdn30.com", source="https://beian.miit.gov.cn/", is_leaf=True),
        CNAMEPattern(suffix=".cdn40.com", source="https://beian.miit.gov.cn/", is_leaf=True),
        CNAMEPattern(suffix=".cdn90.com", source="https://beian.miit.gov.cn/", is_leaf=True),
        CNAMEPattern(suffix=".cdn90.org", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".cdnetgdns.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".cdngtm.cn", source="https://beian.miit.gov.cn/", is_leaf=True),
        CNAMEPattern(suffix=".cdnmg.com", source="https://beian.miit.gov.cn/", is_leaf=True),
        CNAMEPattern(suffix=".cloud-way.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".cloud365msp.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".cloudsway.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".cloudway365.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".cloudway724.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".cloudwaymsp.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".cnccdn.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".cncdomain.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".cncgdns.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".cncovs.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".cusdvs.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".d4p88.net", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".dlbwscs.cn", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".dnsgtm.com", source="https://beian.miit.gov.cn/", is_leaf=True),
        CNAMEPattern(suffix=".dnsguest.com", source="https://beian.miit.gov.cn/", is_leaf=True),
        CNAMEPattern(suffix=".eastday.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".ec988.net", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".ecp-cloud.net", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".edgekey-staging.net.cn", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".edgekey-staging88.net", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".edgekey.net.cn", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".edgekey88.net", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".edgestreams88.net", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".edgesuite-staging.net.cn", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".edgesuite-staging88.net", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".edgesuite.net.cn", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".edgesuite88.net", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".fmsdlb.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".fmssrc.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".haplat.net", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".hdtgtm.com", source="https://beian.miit.gov.cn/", is_leaf=True),
        CNAMEPattern(suffix=".hntncdn.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".iask.in", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".idnscloud.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".kandianzixun.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".lxcdns.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".lxdas.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".lxdfs.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".lxdms.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".lxdns.cn", source="https://beian.miit.gov.cn/", is_leaf=True),
        CNAMEPattern(
            suffix=".lxdns.com", pattern=r"${domain}.lxdns.com", source="https://beian.miit.gov.cn/", is_leaf=True
        ),
        CNAMEPattern(suffix=".lxdus.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".lxdvs.info", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".lxdvsss.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".lxdws.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".maasdk.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".matocloud.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".mileweb.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".msp724.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".mspbigops.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".mspcloudway.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".mwcname.com", source="https://beian.miit.gov.cn/", is_leaf=True),
        CNAMEPattern(suffix=".ngqtlglb.info", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".ogccdn.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".ourcdns.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".ourcloudsec.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".ourdlbs.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".ourdvs.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".ourdvs.net", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".ourdvsss.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".ourdvsssvip.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".ourdvsvip.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".ourdxz.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".ourfdn.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".ourglb0.cn", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".ourglb0.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".ourhlb.info", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".ourltc.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".oursec1.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".ourwebat.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".ourwebcdn.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".ourwebcdnvip.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".ourwebpic.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".ourwscs.cn", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".ovdlb.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".ovhlb.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".picdlb.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".picp.io", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".qidian.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".qtlcdn.cn", source="https://beian.miit.gov.cn/", is_leaf=True),
        CNAMEPattern(suffix=".qtlcdn.com", source="https://beian.miit.gov.cn/", is_leaf=True),
        CNAMEPattern(suffix=".qtlcdn.net", source="https://beian.miit.gov.cn/", is_leaf=True),
        CNAMEPattern(suffix=".qtlcdn360.info", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".qtlcdn360.top", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".qtlcdn360.xin", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".qtlcdn360.xyz", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".qtlcdncn.info", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".qtlglb.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".qtlgslb.cn", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".qtlgslbcn.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".qtlgslbcn.info", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".qtlgslbcn.net", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".quantilcn.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".quantilcn.net", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".quantilng.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".scdnga.cn", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".scdnga.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".scdnga.net", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".scdngc.net", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".sgccdn.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".speedcdns.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".speedws.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".srip.net.cn", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".srip88.net", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".tl53.net", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".tl88.net", source="https://beian.miit.gov.cn/", is_leaf=True),
        CNAMEPattern(suffix=".tl88c.net", source="https://beian.miit.gov.cn/", is_leaf=True),
        CNAMEPattern(suffix=".vicp.cc", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".voddlb.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".wangsu.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".wangsucloud.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".wangsutong.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".waycdn.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".wbahw.cn", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".wcsapi.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".wscdn30.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(
            suffix=".wscdns.com", pattern=r"${domain}.wscdns.com", source="https://beian.miit.gov.cn/", is_leaf=True
        ),
        CNAMEPattern(suffix=".wscdnss.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".wscloudsec.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".wscloudvpn.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".wscvdns.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(
            suffix=".wscvip.cn", pattern=r"${domain}.wscvip.cn", source="https://beian.miit.gov.cn/", is_leaf=True
        ),
        CNAMEPattern(suffix=".wscvip.com", pattern=r"${domain}.wscvip.com", is_leaf=True),
        CNAMEPattern(suffix=".wscvip.top", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".wsdlb.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".wsdns.top", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(
            suffix=".wsdvs.com", pattern=r"${domain}.wsdvs.com", source="https://beian.miit.gov.cn/", is_leaf=True
        ),
        CNAMEPattern(suffix=".wsglb0.cn", pattern=r"${domain}.wsglb0.cn", is_leaf=True),
        CNAMEPattern(suffix=".wsglb0.com", pattern=r"${domain}.wsglb0.com", is_leaf=True),
        CNAMEPattern(suffix=".wsgtm.cn", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".wsgtm1.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".wsgtm2.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".wsgtm3.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".wshttpdns.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".wsipv6.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".wskam.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".wsngclouddns.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".wsngcvdns.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".wsnps.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".wsoss.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".wsoversea.com", source="https://beian.miit.gov.cn/", is_leaf=True),
        CNAMEPattern(suffix=".wsoversea.info", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".wsoversea.net", source="https://beian.miit.gov.cn/", is_leaf=True),
        CNAMEPattern(suffix=".wsoversea.org", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(
            suffix=".wsssec.com", pattern=r"${domain}.wsssec.com", source="https://beian.miit.gov.cn/", is_leaf=True
        ),
        CNAMEPattern(suffix=".wssvip.cn", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".wssvs.net", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".wssyun.com", source="https://beian.miit.gov.cn/"),
        CNAMEPattern(suffix=".wswebcdn.cn", source="https://beian.miit.gov.cn/", is_leaf=True),
        CNAMEPattern(suffix=".wswebpic.com", pattern=r"${domain}.wswebpic.com", is_leaf=True),
        CNAMEPattern(suffix=".wswebpic.info", source="https://beian.miit.gov.cn/"),
        # ;; ANSWER SECTION:
        # apps.samsung.com.       0       IN      CNAME   apps.gw.samsungapps.com.
        # apps.gw.samsungapps.com. 0      IN      CNAME   apps.samsung.com.gslb.cdnetworks.net.
        # apps.samsung.com.gslb.cdnetworks.net. 7200 IN CNAME apps.samsung.com.wtxcdn.com.
        # apps.samsung.com.wtxcdn.com. 0  IN      A       138.113.26.159
        CNAMEPattern(suffix=".wtxcdn.com", source="https://beian.miit.gov.cn/", is_root=False, is_leaf=True),
        CNAMEPattern(suffix=".yuewen.com", source="https://beian.miit.gov.cn/"),
    ],
    cidr=BGPViewCIDR(query_term_list=["wangsu"]),
)
